@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for GNU Prolog 1.4.5 (and later versions)
-%  Last updated on June 13, 2023
+%  Last updated on July 13, 2023
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  SPDX-FileCopyrightText: 1998-2023 Paulo Moura <pmoura@logtalk.org>
@@ -703,24 +703,28 @@ message_queue_destroy(_) :- fail.
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
-:- multifile('$logtalk#0.print_message_token#4'/5).
-:- dynamic('$logtalk#0.print_message_token#4'/5).
+:- if((current_prolog_flag(version_data, gprolog(Major,Minor,Patch)), Major:Minor:Patch @< 1:6:0)).
 
-% workaround non-standard format/3 predicate feature that uses "%" as a
-% format control sequence
+	:- multifile('$logtalk#0.print_message_token#4'/5).
+	:- dynamic('$logtalk#0.print_message_token#4'/5).
 
-'$logtalk#0.print_message_token#4'(Stream, _, Format-Args, _, _) :-
-	atom_codes(Format, FormatCodes),
-	'$lgt_gnu_filter_format_codes'(FormatCodes, FilteredFormatCodes),
-	format(Stream, FilteredFormatCodes, Args).
+	% workaround non-standard format/3 predicate feature that uses "%"
+	% as a format control sequence; changed to "~%" in version 1.6.0
 
-'$lgt_gnu_filter_format_codes'([], []).
-'$lgt_gnu_filter_format_codes'([0'%| Codes], [0'%, 0'%| FilteredCodes]) :-
-	!,
-	'$lgt_gnu_filter_format_codes'(Codes, FilteredCodes).
-'$lgt_gnu_filter_format_codes'([Code| Codes], [Code| FilteredCodes]) :-
-	!,
-	'$lgt_gnu_filter_format_codes'(Codes, FilteredCodes).
+	'$logtalk#0.print_message_token#4'(Stream, _, Format-Args, _, _) :-
+		atom_codes(Format, FormatCodes),
+		'$lgt_gnu_filter_format_codes'(FormatCodes, FilteredFormatCodes),
+		format(Stream, FilteredFormatCodes, Args).
+
+	'$lgt_gnu_filter_format_codes'([], []).
+	'$lgt_gnu_filter_format_codes'([0'%| Codes], [0'%, 0'%| FilteredCodes]) :-
+		!,
+		'$lgt_gnu_filter_format_codes'(Codes, FilteredCodes).
+	'$lgt_gnu_filter_format_codes'([Code| Codes], [Code| FilteredCodes]) :-
+		!,
+		'$lgt_gnu_filter_format_codes'(Codes, FilteredCodes).
+
+:- endif.
 
 
 
