@@ -1,10 +1,10 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for Quintus Prolog 3.3~3.5
-%  Last updated on May 28, 2023
+%  Last updated on June 13, 2023
 %
 %  This file is part of Logtalk <https://logtalk.org/>
-%  Copyright 1998-2023 Paulo Moura <pmoura@logtalk.org>
+%  SPDX-FileCopyrightText: 1998-2023 Paulo Moura <pmoura@logtalk.org>
 %  SPDX-License-Identifier: Apache-2.0
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
@@ -539,6 +539,8 @@ call(F, A1, A2, A3, A4, A5, A6) :-
 '$lgt_default_flag'(trivial_goal_fails, warning).
 '$lgt_default_flag'(always_true_or_false_goals, warning).
 '$lgt_default_flag'(lambda_variables, warning).
+'$lgt_default_flag'(grammar_rules, warning).
+'$lgt_default_flag'(arithmetic_expressions, warning).
 '$lgt_default_flag'(suspicious_calls, warning).
 '$lgt_default_flag'(underscore_variables, singletons).
 % optional features compilation flags:
@@ -1165,6 +1167,14 @@ atomic_list_concat([], _, '').
 	fail.
 
 
+% '$lgt_current_module_predicate'(+atom, +predicate_indicator)
+%
+% succeeds when Module defines Predicate
+
+'$lgt_current_module_predicate'(Module, Predicate) :-
+	current_predicate(Module:Predicate).
+
+
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
